/*-- Copyright (c) 2016 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/ 
/*
$Revision: 1.1.2.3 $
$Date: 2016/02/24 05:11:18 $
Model         Insurance DDS 5.8 HF1
Subject Area  Entire
Model Version 
Name          idds_create_hf_tables.sas
DBMS          Oracle
Created       17-02-2016 11:44:16
* Copyright (c) 2016 by SAS Institute Inc., Cary, NC 27513
*/
%MACRO idds_create_hf_tables(AUTHDOMAIN=, USER=, PATH=, SCHEMA=, fileloc=);
%let connstr=;
%IF (&SCHEMA > "" AND %INDEX(&SCHEMA, ".") = 0) %then %LET SCHEMA=%str(&SCHEMA).;

%if (&PATH > "") %then %do;
   %let connstr = &connstr PATH=&PATH;
%end;
%IF (&AUTHDOMAIN > "") %then %do;
   %let connstr=AUTHDOMAIN=&AUTHDOMAIN &connstr;
%end;
%else %do;
      %let connstr=DBPROMPT=YES USER=&USER &connstr;
%end;


%let db_pass_through_start = EXECUTE (;
%let db_pass_through_end = )BY ORACLE;

/* Script to rename the existing tables present in the hot fix */

PROC SQL NOERRORSTOP; 

  CONNECT TO ORACLE (&connstr);
		%include "&fileloc./idds_rename_existing_hf_tables.sas";
  DISCONNECT FROM ORACLE;
  
QUIT; 

/* Script to create the new and the modified tables in the hot fix */
	  
PROC SQL NOERRORSTOP;
	  
CONNECT TO ORACLE (&connstr);
  %include "&fileloc./analytical_model_target_period.sas";
  %include "&fileloc./application_details.sas";
  %include "&fileloc./assessment_rating_grade.sas";
  %include "&fileloc./bond_instrument.sas";
  %include "&fileloc./capital_allocation.sas";
  %include "&fileloc./capital_cost.sas";
  %include "&fileloc./capital_type.sas";
  %include "&fileloc./code_language.sas";
  %include "&fileloc./conversion_schedule.sas";
  %include "&fileloc./counterparty.sas";
  %include "&fileloc./credit_facility.sas";
  %include "&fileloc./credit_facility_transfer_rate.sas";
  %include "&fileloc./credit_risk_mitigant.sas";
  %include "&fileloc./curve_role.sas";
  %include "&fileloc./external_org_financial_data.sas";
  %include "&fileloc./financial_account.sas";
  %include "&fileloc./financial_collateral.sas";
  %include "&fileloc./financial_instrument.sas";
  %include "&fileloc./financial_instrument_calc_spec.sas";
  %include "&fileloc./financial_position.sas";
  %include "&fileloc./forward_instrument.sas";
  %include "&fileloc./fra_instrument_leg.sas";
  %include "&fileloc./hedge_group.sas";
  %include "&fileloc./hedge_group_type.sas";
  %include "&fileloc./industry.sas";
  %include "&fileloc./internal_org.sas";
  %include "&fileloc./leg_role.sas";
  %include "&fileloc./liquidity_category_type.sas";
  %include "&fileloc./margin_agreement.sas";
  %include "&fileloc./margin_agreement_assmnt_rating.sas";
  %include "&fileloc./margin_agreement_eligibility.sas";
  %include "&fileloc./margin_agreement_leg.sas";
  %include "&fileloc./margin_agrmnt_colltrl_contract.sas";
  %include "&fileloc./money_market_instrument.sas";
  %include "&fileloc./money_market_type.sas";
  %include "&fileloc./mortgage_account.sas";
  %include "&fileloc./netting_set.sas";
  %include "&fileloc./option_instrument.sas";
  %include "&fileloc./physical_asset.sas";
  %include "&fileloc./pledged_collateral.sas";
  %include "&fileloc./pledged_collateral_assignment.sas";
  %include "&fileloc./portfolio_subtype.sas";
  %include "&fileloc./portfolio_type.sas";
  %include "&fileloc./regulatory_capital.sas";
  %include "&fileloc./risk_factor.sas";
  %include "&fileloc./risk_factor_curve.sas";
  %include "&fileloc./risk_factor_attribute.sas";
  %include "&fileloc./risk_factor_category.sas";
  %include "&fileloc./risk_factor_object_relation.sas";
  %include "&fileloc./risk_factor_object_type.sas";
  %include "&fileloc./risk_factor_relation_type.sas";
  %include "&fileloc./rollover_scheme.sas";
  %include "&fileloc./securitization_pool.sas";
  %include "&fileloc./time_unit_of_measure.sas";
  %include "&fileloc./underwriter_details.sas";
DISCONNECT FROM ORACLE;
QUIT;
%MEND;

/* Do not edit below this line */

/* Initialize IAA */
%iaainit;

/* Run DDL to create table structure in Oracle */
%idds_create_hf_tables(AUTHDOMAIN=&INSUREDDSCFG_AUTHDOMAIN., PATH=&INSUREDDSCFG_ORA_PATH., SCHEMA=&INSUREDDSCFG_DB_SCHEMA., fileloc=&IAADDL_ROOT.);

/* Verify if any error thrown at DB end (only applicable when being executed from SAS Deployment Wizard)*/
%let m_sdw_flg=%sysget(m_sdw_flg);
%insurancedds_error_check(sdw_flg=&m_sdw_flg.);